# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.5.3

No merged PRs

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.5.2a6

([Full Changelog](https://github.com/ASFOpenSARlab/opensarlab-extensions/compare/v1.5.2a5...89db6e8de259564a983c17279c2f07c5ecb61727))

### Bugs fixed

- fix: update documentation button link [#15](https://github.com/ASFOpenSARlab/opensarlab-extensions/pull/15) ([@dgpalmieri](https://github.com/dgpalmieri))

### Documentation improvements

- Update RELEASE.md [#14](https://github.com/ASFOpenSARlab/opensarlab-extensions/pull/14) ([@segallagher](https://github.com/segallagher))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ASFOpenSARlab/opensarlab-extensions/graphs/contributors?from=2025-05-07&to=2025-08-15&type=c))

[@dgpalmieri](https://github.com/search?q=repo%3AASFOpenSARlab%2Fopensarlab-extensions+involves%3Adgpalmieri+updated%3A2025-05-07..2025-08-15&type=Issues) | [@github-actions](https://github.com/search?q=repo%3AASFOpenSARlab%2Fopensarlab-extensions+involves%3Agithub-actions+updated%3A2025-05-07..2025-08-15&type=Issues) | [@segallagher](https://github.com/search?q=repo%3AASFOpenSARlab%2Fopensarlab-extensions+involves%3Asegallagher+updated%3A2025-05-07..2025-08-15&type=Issues)

## 1.5.2a5

([Full Changelog](https://github.com/ASFOpenSARlab/opensarlab-extensions/compare/v1.5.2a4...d61bf76dd02fcd6a306fe2b9e5f0765a16d09f02))

### Bugs fixed

- Sg/update extension actions [#12](https://github.com/ASFOpenSARlab/opensarlab-extensions/pull/12) ([@segallagher](https://github.com/segallagher))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ASFOpenSARlab/opensarlab-extensions/graphs/contributors?from=2025-05-02&to=2025-05-07&type=c))

[@segallagher](https://github.com/search?q=repo%3AASFOpenSARlab%2Fopensarlab-extensions+involves%3Asegallagher+updated%3A2025-05-02..2025-05-07&type=Issues)

## 1.5.2a4

No merged PRs

## 1.5.2a3

No merged PRs

## 1.5.2a2

No merged PRs

## 1.5.2a1

No merged PRs

## 1.5.1

No merged PRs
